@@ -58,7 +58,6 @@ class Q_DECL_HIDDEN FileAbstractUploadJob::Private
 
     QMap<QString, FilePtr> uploadedFiles;
 
-
     bool useContentAsIndexableText;
     File::SerializationOptions serializationOptions = File::NoOptions;
 
@@ -155,7 +154,6 @@ void FileAbstractUploadJob::Private::processNext()
     QUrlQuery query(url);
     query.addQueryItem(QStringLiteral("useContentAsIndexableText"), Utils::bool2Str(useContentAsIndexableText));
 
-    QNetworkRequest request;
     QByteArray rawData;
     QString contentType;
 
@@ -185,10 +183,10 @@ void FileAbstractUploadJob::Private::processNext()
         rawData = File::toJSON(metaData, q->serializationOptions());
         contentType = QStringLiteral("application/json");
     }
+
     url.setQuery(query);
 
-    request.setUrl(url);
-    request.setRawHeader("Authorization", "Bearer " + q->account()->accessToken().toLatin1());
+    QNetworkRequest request(url);
     request.setHeader(QNetworkRequest::ContentLengthHeader, rawData.length());
     request.setHeader(QNetworkRequest::ContentTypeHeader, contentType);
     request.setAttribute(QNetworkRequest::User, filePath);
