@@ -28,6 +28,7 @@
 
 #include <QNetworkRequest>
 #include <QNetworkReply>
+#include <QUrlQuery>
 
 
 using namespace KGAPI2;
@@ -41,12 +42,14 @@ class Q_DECL_HIDDEN PermissionCreateJob::Private
 
     PermissionsList permissions;
     QString fileId;
+    bool supportsAllDrives;
 
   private:
     PermissionCreateJob *const q;
 };
 
 PermissionCreateJob::Private::Private(PermissionCreateJob *parent):
+    supportsAllDrives(true),
     q(parent)
 {
 }
@@ -60,11 +63,13 @@ void PermissionCreateJob::Private::processNext()
 
     const PermissionPtr permission = permissions.takeFirst();
 
-    const QUrl url = DriveService::createPermissionUrl(fileId);
+    QUrl url = DriveService::createPermissionUrl(fileId);
 
-    QNetworkRequest request;
-    request.setRawHeader("Authorization", "Bearer " + q->account()->accessToken().toLatin1());
-    request.setUrl(url);
+    QUrlQuery withDriveSupportQuery(url);
+    withDriveSupportQuery.addQueryItem(QStringLiteral("supportsAllDrives"), Utils::bool2Str(supportsAllDrives));
+    url.setQuery(withDriveSupportQuery);
+
+    QNetworkRequest request(url);
 
     const QByteArray rawData = Permission::toJSON(permission);
     q->enqueueRequest(request, rawData, QStringLiteral("application/json"));
@@ -97,6 +102,16 @@ PermissionCreateJob::~PermissionCreateJob()
     delete d;
 }
 
+bool PermissionCreateJob::supportsAllDrives() const
+{
+    return d->supportsAllDrives;
+}
+
+void PermissionCreateJob::setSupportsAllDrives(bool supportsAllDrives)
+{
+    d->supportsAllDrives = supportsAllDrives;
+}
+
 void PermissionCreateJob::start()
 {
     d->processNext();
